@@ -1,14 +1,12 @@
 import pytest
 
-from rich.console import Console
 from unittest.mock import patch, mock_open
 from uptodate.core import RequirementsScanner
 
 
 @pytest.fixture
 def scanner():
-    console = Console()
-    return RequirementsScanner(console)
+    return RequirementsScanner()
 
 
 @pytest.fixture
