@@ -6,8 +6,7 @@ from uptodate.core import UpToDate, Row
 
 @pytest.fixture
 def uptodate():
-    console = Console()
-    return UpToDate(console)
+    return UpToDate()
 
 
 @pytest.fixture
